@@ -76,8 +76,8 @@ CONFIG_SCHEMA = {
 
 
 class Config(pydantic.BaseModel):
-    keyvalues: typing.Dict[str, jsonlog_cli.pattern.KeyValuePattern]
-    templates: typing.Dict[str, jsonlog_cli.pattern.TemplatePattern]
+    keyvalues: typing.Dict[str, jsonlog_cli.pattern.KeyValuePattern] = {}
+    templates: typing.Dict[str, jsonlog_cli.pattern.TemplatePattern] = {}
 
     @classmethod
     def load(cls, filename: str) -> "Config":
@@ -92,7 +92,7 @@ class Config(pydantic.BaseModel):
 
         if path.exists():
             loaded = config.read(path)
-            config.templates.update(loaded)
+            config.templates.update(loaded.templates)
             config.keyvalues.update(loaded.keyvalues)
 
         return config
@@ -106,12 +106,13 @@ class Config(pydantic.BaseModel):
         return Config(**json.loads(path.read_text(encoding="utf-8")))
 
 
-def configure_logging(path: str) -> None:
+def configure_logging(path: str, level: str) -> None:
     """
     If given a path to a potential logfile, ensure the containing directory exists.
     """
+    logging_level = logging._nameToLevel[level.upper()]
     if path == "-":
-        jsonlog.basicConfig(level=logging.INFO, stream=sys.stderr)
+        jsonlog.basicConfig(level=logging_level, stream=sys.stderr)
     else:
         pathlib.Path(path).parent.mkdir(exist_ok=True)
-        jsonlog.basicConfig(level=logging.INFO, filename=path)
+        jsonlog.basicConfig(level=logging_level, filename=path)
